---
title: PG사 오류코드
description: 각 PG사별 오류코드집을 내려받을 수 있습니다.
targetVersions:
  - v1
---

## NHN KCP

(파일: NHN KCP 오류코드 다운로드)

## KG이니시스

(파일: KG이니시스 오류코드 다운로드)

## 카카오페이

(파일: 카카오페이 오류코드 다운로드)

## 토스페이먼츠

(파일: 토스페이먼츠 오류코드 다운로드)

## KG모빌리언스

(파일: KG모빌리언스 휴대폰 결제 오류코드 다운로드)

(파일: KG모빌리언스 휴대폰 결제 취소 오류코드 다운로드)

## 다날

(파일: 다날 오류코드 다운로드)

## 페이먼트월

[페이먼트월 오류코드 바로가기](https://docs.paymentwall.com/integration/direct/brick/error-codes)
